@@ -2,13 +2,13 @@
  *                   Materials Object Library                  *
  * Class isotropic_tensor : declaration for isotropic material *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.0.0                   *
+ *                   GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2006 PARGUEZ Cristelle
- * copyright  2002,2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2006 PARGUEZ Cristelle
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2002,2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*! \namespace materiol
@@ -41,15 +41,15 @@
     </FONT>
     \endhtmlonly
 
-    Let \f$ \lambda \f$ and \f$ \mu \f$ be two constants. We define a \f$ 4^{th} \f$ order isotropic tensor \f$ \bold{C} \f$ through \f$ \lambda \f$ and \f$ \mu \f$ by \n
+    Let \f$ \lambda \f$ and \f$ \mu \f$ be two constants. We define a \f$ 4^{th} \f$ order isotropic tensor \f$ \boldsymbol{C} \f$ through \f$ \lambda \f$ and \f$ \mu \f$ by \n
     \f$ C_{ijkl} = \lambda \delta_{ij} \delta_{kl} + \mu (\delta_{ik} \delta_{jl} + \delta_{il} \delta_{jk}) \f$
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2006 Cristelle PARGUEZ \n
-            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-    \version 2.0.0
-    \date 2002-2008
+            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+    \version 2.2.0
+    \date 2002-2009
     \bug none
     \warning none
 */
