@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006,2007,2008 COLLARD Christophe
- * copyright  2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -47,32 +47,36 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(___COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__PARAMETERS_H)
 #include "parameters.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include"MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__TENSORS2_H)
-#include"MOL++/tensors2.h"
+#include "MOL++/tensors2.h"
 #endif
 
 #if !defined(__TENSORS3_H)
-#include"MOL++/tensors3.h"
+#include "MOL++/tensors3.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
-#include"MateriOL++/isotropic elasticity tensors.h"
+#include "MateriOL++/isotropic elasticity tensors.h"
 #endif
 
 #if !defined(__TII_H)
-#include"MateriOL++/TII.h"
+#include "MateriOL++/TII.h"
 #endif
 
 #if !defined(__ESHELBY_H)
-#include"MateriOL++/Eshelby.h"
+#include "MateriOL++/Eshelby.h"
 #endif
 
 #if !defined(__AFFICHE_h)
@@ -123,7 +127,7 @@ int test_Eshelby (int detail)
   else result *= (test);
 
   vector<long double> geometry (3,true,R);
-  test = (Siso_analytique == SII.ellipsoid(C,geometry,13,17));
+  test = (Siso_analytique == SII.ellipsoid(C,geometry,14,18));
   if (detail) affiche ("ellipsoid (sphere)", test);
   else result *= (test);
 
@@ -166,8 +170,8 @@ int test_Eshelby (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                     Eshelby test passed \n";
-  else cout << "                     Eshelby test failed \n";
+  if (result) cout << green << "                     Eshelby test passed" << reset;
+  else cout << red << "                     Eshelby test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
