@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006,2007,2008 COLLARD Christophe
- * copyright  2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -47,20 +47,28 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(___COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__PARAMETERS_H)
 #include "parameters.h"
 #endif
 
+#if !defined(__MATRIX_H)
+#include "MOL++/matrix.h"
+#endif
+
 #if !defined(__TENSORS2_H)
-#include"MOL++/tensors2.h"
+#include "MOL++/tensors2.h"
 #endif
 
 #if !defined(__TENSORS4_H)
-#include"MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 #if !defined(__MATERIALS_TOOLBOX_H)
-#include"MateriOL++/MatOoLbox.h"
+#include "MateriOL++/MatOoLbox.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
@@ -115,11 +123,30 @@ int test_MatOoLbox (int detail)
   if (detail) affiche ("constitutive equation", strain == ((S||stress) + (S||M)*To) && stress == constitutive_equation(C,M,strain,To,-1));
   else result *= (strain == ((S||stress) + (S||M)*To) && stress == constitutive_equation(C,M,strain,To,-1));
 
+  matrix<long double> P, P1(3,3), P2(3,3), P3(3,3);
+  long double phi1=73.464, phi=104.504, phi2=34.5;
+  P1(1,1) = P1(2,2) = cos(phi1);
+  P1(2,1) = sin(phi1);
+  P1(1,2) = -P1(2,1);
+  P2(2,2) = P2(3,3) = cos(phi);
+  P2(3,2) = sin(phi);
+  P2(2,3) = -P2(3,2);
+  P3(1,1) = P3(2,2) = cos(phi2);
+  P3(2,1) = sin(phi2);
+  P3(1,2) = -P3(2,1);
+  P1(3,3) = P2(1,1) = P3(3,3) = 1;
+  P = P1 * P2 * P3;
+
+  if (detail) affiche ("local2global basis", P == local2global_basis(phi1,phi,phi2));
+  else result *= (P == local2global_basis(phi1,phi,phi2));
+
+  if (detail) affiche ("global2local basis", t(P) == global2local_basis(phi1,phi,phi2));
+  else result *= (t(P) == global2local_basis(phi1,phi,phi2));
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                    MatOoLbox test passed \n";
-  else cout<< "                    MatOoLbox test failed \n";
+  if (result) cout << green << "                    MatOoLbox test passed" << reset;
+  else cout << red << "                    MatOoLbox test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
