@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006,2007,2008 COLLARD Christophe
- * copyright  2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -47,24 +47,28 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(___COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__PARAMETERS_H)
 #include "parameters.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include"MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__TENSORS4_H)
-#include"MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
-#include"MateriOL++/isotropic elasticity tensors.h"
+#include "MateriOL++/isotropic elasticity tensors.h"
 #endif
 
 #if !defined(__TII_H)
-#include"MateriOL++/TII.h"
+#include "MateriOL++/TII.h"
 #endif
 
 #if !defined(__AFFICHE_h)
@@ -114,8 +118,8 @@ int test_TII (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                       TII test passed \n";
-  else cout << "                       TII test failed \n";
+  if (result) cout << green << "                       TII test passed" << reset;
+  else cout << red << "                       TII test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
