@@ -1,12 +1,12 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2006 PARGUEZ Cristelle
- * copyright  2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2006 PARGUEZ Cristelle
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -52,20 +52,24 @@
 #include "parameters.h"
 #endif
 
+#if !defined(___COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(___VECTORS_H)
-#include"MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(___MATRIX_H)
-#include"MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(___TENSOR4_H)
-#include"MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 #if !defined(__ISOTROPIC_TENSORS_H)
-#include"MateriOL++/isotropic tensors.h"
+#include "MateriOL++/isotropic tensors.h"
 #endif
 
 #if !defined(__AFFICHE_h)
@@ -479,8 +483,8 @@ int test_isotropic_tensor (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                 isotropic tensor test passed \n";
-  else cout << "                 isotropic tensor test failed \n";
+  if (result) cout << green << "                 isotropic tensor test passed" << reset;
+  else cout << red << "                 isotropic tensor test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
