@@ -1,10 +1,10 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2007,2008 COLLARD Christophe
- * copyright  2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright © 2007,2008,2009 COLLARD Christophe
+ * copyright © 2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  ***************************************************************/
 
 /*
@@ -46,28 +46,32 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(___COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__PARAMETERS_H)
 #include "parameters.h"
 #endif
 
 #if !defined(___VECTORS_H)
-#include"MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include"MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(___TENSOR4_H)
-#include"MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
-#include"MateriOL++/isotropic elasticity tensors.h"
+#include "MateriOL++/isotropic elasticity tensors.h"
 #endif
 
 #if !defined(__ORTHOTROPIC_TENSORS_H)
-#include"MateriOL++/orthotropic tensors.h"
+#include "MateriOL++/orthotropic tensors.h"
 #endif
 
 #if !defined(__AFFICHE_h)
@@ -144,8 +148,8 @@ int test_orthotropic_tensor (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                orthotropic tensor test passed \n";
-  else cout << "                orthotropic tensor test failed \n";
+  if (result) cout << green << "                orthotropic tensor test passed" << reset;
+  else cout << red << "                orthotropic tensor test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
