@@ -1,12 +1,12 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006,2007,2008 COLLARD Christophe
- * copyright  2005,2006 BERBENNI Stephane
- * copyright  2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2005,2006 BERBENNI Stephane
+ * copyright © 2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -56,28 +56,44 @@
 #include <time.h>
 #endif
 
+#if !defined(___COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__ISOTROPIC_TENSORS_TEST_H)
-#include"isotropic tensors-test.h"
+#include "isotropic tensors-test.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_TEST_H)
-#include"isotropic elasticity tensors-test.h"
+#include "isotropic elasticity tensors-test.h"
 #endif
 
 #if !defined(__CUBIC_TENSORS_TEST_H)
-#include"cubic tensors-test.h"
+#include "cubic tensors-test.h"
 #endif
 
 #if !defined(__CUBIC_ELASTICITY_TENSORS_TEST_H)
-#include"cubic elasticity tensors-test.h"
+#include "cubic elasticity tensors-test.h"
 #endif
 
 #if !defined(__ORTHOTROPIC_TENSORS_TEST_H)
-#include"orthotropic tensors-test.h"
+#include "orthotropic tensors-test.h"
+#endif
+
+#if !defined(__TRANSVERSELY_ISOTROPIC_TENSORS_TEST_H)
+#include "transversely isotropic tensors-test.h"
+#endif
+
+#if !defined(__TRANSVERSELY_ISOTROPIC_ELASTIC_TENSORS_TEST_H)
+#include "transversely isotropic elastic tensors-test.h"
 #endif
 
 #if !defined(__TII_TEST_H)
-#include"TII-test.h"
+#include "TII-test.h"
+#endif
+
+#if !defined(__PII_TEST_H)
+#include "PII-test.h"
 #endif
 
 //#if !defined(__TIJ_TEST_H)
@@ -85,11 +101,27 @@
 //#endif
 
 #if !defined(__ESHELBY_TEST_H)
-#include"Eshelby-test.h"
+#include "Eshelby-test.h"
+#endif
+
+#if !defined(__SCHMID_TENSOR_TEST_H)
+#include "Schmid tensor-test.h"
+#endif
+
+#if !defined(__SYSTEMS_TEST_H)
+#include "systems-test.h"
+#endif
+
+#if !defined(__LOADING_TEST_H)
+#include "loading-test.h"
 #endif
 
 #if !defined(__MATERIALS_TOOLBOX_TEST_H)
-#include"MatOoLbox-test.h"
+#include "MatOoLbox-test.h"
+#endif
+
+#if !defined(__WALPOLE_TEST_H)
+#include "walpole-test.h"
 #endif
 
 using namespace std;
@@ -162,6 +194,30 @@ main()
 
   cout << endl;
 
+  detail = 0;
+  start_main = start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "----------------transversely isotropic tensor---------------- \n";
+    //=======================================================================
+  result *= test_transversely_isotropic_tensor(detail);
+  end = clock();
+  cout << "cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
+  detail = 0;
+  start_main = start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "------------transversely isotropic elastic tensor------------ \n";
+    //=======================================================================
+  result *= test_transversely_isotropic_elastic_tensor(detail);
+  end = clock();
+  cout << "cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
   detail = 0;
   start = clock();
   if (detail)
@@ -174,6 +230,18 @@ main()
 
   cout << endl;
 
+  detail = 0;
+  start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "-----------------------------PII----------------------------- \n";
+    //=======================================================================
+  result *= test_PII(detail);
+  end = clock();
+  cout << "cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
   /*
   detail = 0;
   start = clock();
@@ -200,6 +268,42 @@ main()
 
   cout << endl;
 
+  detail = 0;
+  start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "------------------------Schmid tensor------------------------ \n";
+    //=======================================================================
+  result *= test_Schmid_tensor(detail);
+  end = clock();
+  cout << "cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
+  detail = 0;
+  start_main = start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "---------------------------systems--------------------------- \n";
+    //=======================================================================
+  result *= test_systems(detail);
+  end = clock();
+  cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
+  detail = 0;
+  start_main = start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "---------------------------loading--------------------------- \n";
+    //=======================================================================
+  result *= test_loading(detail);
+  end = clock();
+  cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
   detail = 0;
   start = clock();
   if (detail)
@@ -212,6 +316,18 @@ main()
 
   cout << endl;
 
+  detail = 0;
+  start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "---------------------------walpole--------------------------- \n";
+    //=======================================================================
+  result *= test_walpole(detail);
+  end = clock();
+  cout << "cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
   end_main = clock();
 
   bool test = true;
@@ -226,8 +342,8 @@ main()
   file2.close();
 
   cout << "============================================================== \n";
-  if (result) cout << "-------OK-----------end of MateriOL++ tests-----------OK------ \n";
-  else cout << "-----FAILED---------end of MateriOL++ tests---------FAILED---- \n";
+  if (result) cout << green << "-------OK-----------end of MateriOL++ tests-----------OK------" << reset;
+  else cout << red << "-----FAILED---------end of MateriOL++ tests---------FAILED----" << reset;
   cout << "============================================================== \n";
 
   cout<<"cpu time : " << (long double)(end_main-start_main)/CLOCKS_PER_SEC << endl;
